# plots

See {doc}`../api/plots` for the full API reference.

Interactive plot examples:

- {doc}`daily_profiles` — Daily profiles: overview, mean, decomposed, and overlayed (Plotly)
- {doc}`heatmap_median_weeks` — Heatmap of median values per hour by weekday and season (Plotly)
- {doc}`heatmap_calendar` — Calendar heatmap of daily aggregated values (Plotly)
- {doc}`mollier_hx` — Mollier h,x-diagram / psychrometric chart (D3.js)
- {doc}`energy_signature` — Building energy signature: simple scatter and Proposed Energy Signature (Plotly)
- {doc}`decomposition` — STL time series decomposition: long-term (monthly) and short-term (15-min) (Plotly)
- {doc}`density_seasons` — Density plot of a value by season (Plotly)
- {doc}`seasonal` — Seasonal plots: overlapping, miniplots, before/after, polar (Plotly)
- {doc}`sum_frequency` — Sum frequency / duration curve plot (Plotly)
- {doc}`comfort` — Comfort plots: SIA 180 thermal comfort, temperature vs humidity (Plotly)
